"""Tools for the Advent of Code."""
from .puzzle import Puzzle

__all__ = ["Puzzle"]
